// #pragma comment(linker, "/stack:200000000")
// #pragma GCC optimize("Ofast,no-stack-protector")
// #pragma GCC target("sse,sse2,sse3,ssse3,sse4,popcnt,abm,mmx,avx,avx2,tune=native")
// #pragma GCC optimize("unroll-loops")

#include <stdio.h>
#include <bits/stdc++.h>

#ifdef PERVEEVM_LOCAL
    #define debug(x...) std::cerr << "[DEBUG]\t" << __LINE__ << ":\t" << (#x) << " = "; print_debug(x)
#else
    #define debug(x...) 238
#endif

#define fastIO std::ios_base::sync_with_stdio(false); std::cin.tie(0); std::cout.tie(nullptr)
#define NAME "File"

using ll = long long;
using ld = long double;

#ifdef PERVEEVM_LOCAL
    std::mt19937 rnd(238);
#else
    std::mt19937 rnd(std::chrono::high_resolution_clock::now().time_since_epoch().count());
#endif

template<typename T1, typename T2>
std::ostream& operator<<(std::ostream& out, const std::pair<T1, T2>& p) {
    out << "(" << p.first << ", " << p.second << ")";
    return out;
}

template<size_t index, typename T>
std::ostream& print_tuple(std::ostream& out, const T& t) {
    if constexpr (index == std::tuple_size<T>::value) {
        out << ")";
        return out;
    } else {
        if (index > 0) {
            out << ", ";
        } else {
            out << "(";
        }
        out << std::get<index>(t);
        return print_tuple<index + 1, T>(out, t);
    }
}

template<typename ...T>
std::ostream& operator<<(std::ostream& out, const std::tuple<T...>& t) {
    return print_tuple<0, std::tuple<T...>>(out, t);
}

template<typename Container, typename = decltype(std::begin(std::declval<Container>()))>
typename std::enable_if<!std::is_same<Container, std::string>::value, std::ostream&>::type
operator<<(std::ostream& out, const Container& container) {
    out << "{";
    for (auto it = container.begin(); it != container.end(); ++it) {
        if (it != container.begin()) {
            out << ", ";
        }
        out << *it;
    }
    out << "}";
    return out;
}

void print_debug() {
    std::cerr << std::endl;
}

template<typename T, typename... V>
void print_debug(const T& value, const V&... others) {
    std::cerr << value;
    if (sizeof...(others) != 0) {
        std::cerr << ", ";
        print_debug(others...);
    } else {
        std::cerr << std::endl;
    }
}

template<typename T>
bool smin(T& a, const T& b) {
    if (b < a) {
        a = b;
        return true;
    }
    return false;
}

template<typename T>
bool smax(T& a, const T& b) {
    if (a < b) {
        a = b;
        return true;
    }
    return false;
}

const double PI = atan2(0.0, -1.0);
const int INF = 0x3f3f3f3f;
const ll LINF = (ll)2e18;
const int N = 100100;

struct Node {
    int l, r, sum;

    Node() : l(-1), r(-1), sum(0) {}

    Node(int _l, int _r, int _sum) : l(_l), r(_r), sum(_sum) {}
};

int n;
int p[N], rp[N];
std::pair<int, int> queries[N];
std::vector<Node> tree(4 * N);
int roots[N];

void build(int v, int l, int r) {
    if (l + 1 == r) {
        return;
    }

    int m = (l + r) / 2;
    build(v * 2 + 1, l, m);
    build(v * 2 + 2, m, r);
    tree[v] = Node(v * 2 + 1, v * 2 + 2, 0);
}

int get(int v, int l, int r, int ql, int qr) {
    if (r <= ql || qr <= l) {
        return 0;
    }
    if (ql <= l && r <= qr) {
        return tree[v].sum;
    }

    int m = (l + r) / 2;
    return get(tree[v].l, l, m, ql, qr) + get(tree[v].r, m, r, ql, qr);
}

int add(int v, int l, int r, int pos, int val) {
    if (l + 1 == r) {
        tree.emplace_back(l, r, tree[v].sum + val);
        return (int)tree.size() - 1;
    }

    int m = (l + r) / 2;
    int newL = tree[v].l, newR = tree[v].r;
    if (pos < m) {
        newL = add(tree[v].l, l, m, pos, val);
    } else {
        newR = add(tree[v].r, m, r, pos, val);
    }

    tree.emplace_back(newL, newR, tree[newL].sum + tree[newR].sum);
    return (int)tree.size() - 1;
}

int findKth(int pref, int k) {
    int root = roots[pref];

    int l = -1, r = n;
    while (r - l > 1) {
        int m = (l + r) / 2;
        int cnt = get(root, 0, n, 0, m);
        if (cnt > k) {
            r = m;
        } else {
            l = m;
        }
    }

    // kth element equals to l
    debug(pref, k, l, rp[l]);
    assert(rp[l] < pref);
    return rp[l];
}

void run() {
    int q, k;
    scanf("%d%d%d", &n, &q, &k);

    for (int i = 0; i < n; ++i) {
        scanf("%d", &p[i]);
        --p[i];
        rp[p[i]] = i;
    }

    build(0, 0, n);

    roots[0] = 0;
    for (int i = 0; i < n; ++i) {
        roots[i + 1] = add(roots[i], 0, n, p[i], 1);
        // debug(get(roots[i + 1]))
    }

    for (int i = 0; i < q; ++i) {
        scanf("%d%d", &queries[i].first, &queries[i].second);
        --queries[i].first;
        --queries[i].second;
    }

    --k;
    for (int i = q - 1; i >= 0; --i) {
        auto[l, r] = queries[i];
        if (k < l || k > r) {
            continue;
        }

        int len = r - l + 1;
        int pos = findKth(len, k - l);
        k = l + pos;
    }

    printf("%d\n", k + 1);
}

int main(void) {
    // freopen(NAME".in", "r", stdin);
    // freopen(NAME".out", "w", stdout);

    #ifdef PERVEEVM_LOCAL
        auto start = std::chrono::high_resolution_clock::now();
    #endif

    run();

    #ifdef PERVEEVM_LOCAL
        auto end = std::chrono::high_resolution_clock::now();
        std::cerr << "Execution time: "
                  << std::chrono::duration_cast<std::chrono::milliseconds>(end - start).count()
                  << " ms" << std::endl;
    #endif

    return 0;
}
